package jp.co.asterisk.asreader.a60d.demoapp;

import android.content.Context;
import android.os.Bundle;

import androidx.annotation.ColorRes;
import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;

import android.util.Log;
import android.view.KeyEvent;
import android.view.View;

import androidx.fragment.app.Fragment;
import androidx.navigation.NavController;
import androidx.navigation.NavDestination;
import androidx.navigation.Navigation;
import androidx.navigation.Navigator;
import androidx.navigation.ui.AppBarConfiguration;
import androidx.navigation.ui.NavigationUI;

import jp.co.asterisk.asreader.a60d.demoapp.databinding.ActivityMainBinding;
import jp.co.asterisk.asreader.a60d.demoapp.fragments.base.BaseFragment;
import jp.co.asterisk.asreader.a60d.demoapp.util.AppSharedData;
import jp.co.asterisk.asreader.a60d.sdk.AsReaderSDK;
import jp.co.asterisk.asreader.a60d.sdk.event.ASKManagerCallBack;
import jp.co.asterisk.asreader.a60d.sdk.event.DeviceManagerCallback;
import jp.co.asterisk.asreader.a60d.sdk.protocol.JVMAModel;
import jp.co.asterisk.asreader.a60d.sdk.protocol.JVMARecord;
import jp.co.asterisk.asreader.a60d.sdk.type.PacketValue;
import jp.co.asterisk.asreader.a60d.sdk.type.ask.TriggerStatus;
import jp.co.asterisk.asreader.a60d.sdk.util.SDKLog;

import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;
import android.widget.Toast;

import java.util.List;
import java.util.Map;
import java.util.Objects;

public class MainActivity extends AppCompatActivity implements DeviceManagerCallback, ASKManagerCallBack {

    private static final String TAG = "[A60D DemoApp] : " + MainActivity.class.getSimpleName();

    private AppBarConfiguration appBarConfiguration;
    private ActivityMainBinding binding;
    private boolean isScrollBottom = true;

    private Navigator navigator;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        binding = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());

        AppSharedData.getInstance().initialize(getApplicationContext());
        AppSharedData.getInstance().setTerminalPassword("9158597797");
        AppSharedData.getInstance().setOfflineSystemPassword("7977958519");


        setSupportActionBar(binding.toolbar);
//        binding.toolbar.setElevation(10);
        getSupportActionBar().setDisplayShowTitleEnabled(false);
        showLeftButton(false);

        AsReaderSDK.getInstance().getDeviceManager().setDeviceManagerCallback(this);
        AsReaderSDK.getInstance().getASKManager().setAskManagerCallBack(this);
        AsReaderSDK.getInstance().initialize(getApplicationContext());
        AsReaderSDK.getInstance().changeSDKLogType(SDKLog.LogType.LogType_APP);
        AsReaderSDK.getInstance().setLogLevel(SDKLog.LogLevel.Debug);
        AsReaderSDK.getInstance().setLog(true);
        binding.sdkVersionTextView.setText("SDK Ver: " + AsReaderSDK.getInstance().getVersion());

        binding.scrollView.setOnScrollChangeListener(scrollChangeListener);

        binding.logClearImageButton.setOnClickListener(v -> {
            binding.logTextView.setText("");
        });
    }

    @Override
    protected void onStart() {
        super.onStart();
        setBatteryState(0);

//        // 復帰した場合
//        if (AsReaderSDK.getInstance().getDeviceManager() != null) {
//            // 再接続
//            AsReaderSDK.getInstance().getDeviceManager().notifyApplicationActive();
//        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();

        AsReaderSDK.getInstance().getDeviceManager().setPower(false);
        AsReaderSDK.getInstance().getDeviceManager().destroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
//        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onSupportNavigateUp() {
        onClickBackButton();
        return super.onSupportNavigateUp();
//        NavController navController = Navigation.findNavController(this, R.id.nav_host_fragment_content_main);
//        return NavigationUI.navigateUp(navController, appBarConfiguration)
//                || super.onSupportNavigateUp();
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            onClickBackButton();
            return false;
        }

        return super.onKeyDown(keyCode, event);
    }

    /**
     * Public method
     */
    private Fragment getCurrentFragment() {
        Fragment navHostFragment = getSupportFragmentManager().findFragmentById(R.id.nav_host_fragment_content_main);
        return (navHostFragment != null) ? navHostFragment.getChildFragmentManager().getFragments().get(0) : null;
    }

    private void onClickBackButton() {
        runOnUiThread(() -> {

            Fragment currentFragment = getCurrentFragment();
            if (currentFragment instanceof BaseFragment) {
                ((BaseFragment) currentFragment).onClickBackButton();
            }
        });
    }

    public void showBackButton(boolean show) {
        Objects.requireNonNull(getSupportActionBar()).setDisplayShowHomeEnabled(show);
        getSupportActionBar().setDisplayHomeAsUpEnabled(show);
    }

    public void showLeftButton(boolean show) {
        Objects.requireNonNull(getSupportActionBar()).setDisplayShowHomeEnabled(show);
        getSupportActionBar().setDisplayHomeAsUpEnabled(show);
    }

    public void showToast(String message) {
        Toast.makeText(this, message, Toast.LENGTH_SHORT).show();
    }

    public void setToolbarTitle(String title) {

        if( binding.titleTextView!=null && title!=null) {
            binding.titleTextView.setText(title);
        }
    }

    public void resetResultText() {
        binding.resultTextView.setText(getString(R.string.connect_result_none));
        binding.resultTextView.setBackgroundColor(getColor(R.color.white));
        binding.resultTextView.setTextColor(getColor(R.color.black));
    }

    public void setResultTextColor(@ColorRes int color) {
        binding.resultTextView.setTextColor(getColor(color));
    }

    public void setResultTextVisibility(int visibility) {
        binding.resultTextView.setVisibility(visibility);
    }

    /**
     * Private method
     */
    public void setBatteryState(int battery) {
        int batteryImageID = R.drawable.btb_0;

        if (battery > 80) {
            batteryImageID = R.drawable.btb_100;

        } else if (battery > 60) {
            batteryImageID = R.drawable.btb_75;

        } else if (battery > 40) {
            batteryImageID = R.drawable.btb_50;

        } else if (battery > 20) {
            batteryImageID = R.drawable.btb_25;
        }

        binding.batteryImageView.setImageDrawable(getDrawable(batteryImageID));
    }

    private void addToLogText(String logText) {
        binding.logTextView.append(logText);
        if (isScrollBottom) {
            binding.scrollView.post(() -> {
                binding.scrollView.fullScroll(View.FOCUS_DOWN);
            });
        }
    }

    private View.OnScrollChangeListener scrollChangeListener = (View v, int scrollX, int scrollY, int oldScrollX, int oldScrollY) -> {
        View content = binding.scrollView.getChildAt(0);
        if (content == null) return;

        isScrollBottom = (scrollY + binding.scrollView.getHeight()) >= content.getHeight();
    };

    /**
     * DeviceManager Callback
     */
    @Override
    public void onConnect(boolean isConnect) {
        runOnUiThread(() -> {
            String msg = "onConnect 状態 : " + isConnect;
            Toast.makeText(getApplicationContext(),msg, Toast.LENGTH_SHORT).show();

            String text = isConnect ? "Connect" : "Disconnect";
            binding.stateTextView.setText(text);

            AsReaderSDK.getInstance().getDeviceManager().setPower(isConnect);

            if (isConnect) {
            } else {
                setBatteryState(0);
                binding.moduleVersionTextView.setText("Module Ver: -");
            }
        });
    }

    @Override
    public void onCompletedPreparation(boolean isPowerOn) {
        if (isPowerOn){
            AsReaderSDK.getInstance().getDeviceManager().getModuleVersion();
        }
    }

    @Override
    public void onReceivedBattery(int battery) {
        runOnUiThread(() -> {
//            String msg = "onReceivedBattery:" + battery;
//            addToLogText(msg + "\r\n");
            setBatteryState(battery);
        });
    }

    @Override
    public void onReceivedTriggerState(TriggerStatus status) {
        runOnUiThread(() -> {
            String msg = "onReceivedTriggerState:" + status;
            showToast(msg);
            addToLogText(msg + "\r\n");
        });
    }

    @Override
    public void onDeviceManagerError(String message) {
        runOnUiThread(() -> {
            String msg = "onReceivedDeviceError:" + message;
            addToLogText(msg + "\r\n");
        });
    }

    @Override
    public void onReceiveModuleVersion(String versionText) {
        runOnUiThread(() -> binding.moduleVersionTextView.setText("Module Ver: " + versionText));
    }

    @Override
    public void onReceivedSettingParameter(Map<String, String> params) {
        runOnUiThread(() -> {
            addToLogText("DeviceParameters:\n");
            for (Map.Entry<String,String> entry : params.entrySet()) {
                addToLogText(entry.getKey() +":" + entry.getValue() + "\n");
            }
        });
    }

    /**
     * ASKManager Callback
     */
    @Override
    public void onReceivedJVMAResult(List<JVMARecord> result, JVMAModel ackNakResult) {
        runOnUiThread(() -> {
            Log.d("TEST1", "onReceivedJVMAResult");
            if (result != null) {
                for (JVMARecord jvmaRecord : result) {
                    addToLogText("Record identifyingCode: " + jvmaRecord.getIdentifyingCode() + "\r\n");
                    addToLogText("Record recordLength: " + jvmaRecord.getRecordLength() + "\r\n");
                    addToLogText("Record itemDigitNumber: " + jvmaRecord.getItemDigitNumber() + "\r\n");

                    for (String item : jvmaRecord.getItems()) {
                        addToLogText("Record item: " + item + "\r\n");
                    }
                }
            }

            if (ackNakResult.getPacketType() == PacketValue.RESPONSE_ACK) {
                binding.resultTextView.setText(getString(R.string.connect_result_success));
                binding.resultTextView.setBackgroundColor(getColor(R.color.blue));
            }
            else if (ackNakResult.getPacketType() == PacketValue.RESPONSE_NAK) {
                binding.resultTextView.setText(getString(R.string.connect_result_error));
                binding.resultTextView.setBackgroundColor(getColor(R.color.red));
            }
            setResultTextColor(R.color.white);
        });
    }

    @Override
    public void onASKManagerError(String message) {
        runOnUiThread(() -> addToLogText("エラー：" + message + "\r\n"));
    }

    @Override
    public void onReceiveASKCommandMessage(String message) {
        runOnUiThread(() -> addToLogText(message + "\r\n"));
    }
}