package jp.co.asterisk.asreader.a60d.demoapp.fragments;

import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.navigation.fragment.NavHostFragment;

import java.util.ArrayList;
import java.util.List;

import jp.co.asterisk.asreader.a60d.demoapp.R;
import jp.co.asterisk.asreader.a60d.demoapp.adapters.SelectListAdapter;
import jp.co.asterisk.asreader.a60d.demoapp.databinding.FragmentHomeBinding;
import jp.co.asterisk.asreader.a60d.demoapp.enums.HomeMenuItems;
import jp.co.asterisk.asreader.a60d.demoapp.fragments.base.BaseFragment;
import jp.co.asterisk.asreader.a60d.sdk.AsReaderSDK;

public class HomeFragment extends BaseFragment {

    public static final String TAG = "[ASR-A60D DemoApp] : " + HomeFragment.class.getSimpleName();

    private List<String> items;

    private FragmentHomeBinding binding;

    @Override
    public View onCreateView(
            LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState
    ) {
        Log.d(TAG, "onCreateView");
        binding = FragmentHomeBinding.inflate(inflater, container, false);

//         setToolbarTitle(getString(R.string.toolbar_title_main));
        return binding.getRoot();
    }

    @Override
    public void onResume() {
        super.onResume();
        getMainActivity().setResultTextVisibility(View.INVISIBLE);
        getMainActivity().setToolbarTitle(getString(R.string.toolbar_title_main));
        getMainActivity().showBackButton(false);
    }

    public void onViewCreated(@NonNull View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        items = new ArrayList<>();
        for (HomeMenuItems command: HomeMenuItems.values()) {
            items.add(command.getName());
        }

        SelectListAdapter selectListAdapter = new SelectListAdapter(this.getContext(), R.layout.select_list_item, items);
        binding.listView.setAdapter(selectListAdapter);
        binding.listView.setOnItemClickListener((parent, view1, position, id) -> {
            Bundle args = new Bundle();

            if (position == HomeMenuItems.COLLECT_DATA.ordinal()) {
                NavHostFragment.findNavController(HomeFragment.this)
                        .navigate(R.id.action_HomeFragment_to_CollectFragment, args);

            } else if (position == HomeMenuItems.SET_DATA.ordinal()) {
                NavHostFragment.findNavController(HomeFragment.this)
                        .navigate(R.id.action_HomeFragment_to_SetDataFragment, args);

            } else if (position == HomeMenuItems.CLEAR_DATA.ordinal()) {
                NavHostFragment.findNavController(HomeFragment.this)
                        .navigate(R.id.action_HomeFragment_to_ClearDataFragment, args);

            } else if (position == HomeMenuItems.SETTING.ordinal()) {
                NavHostFragment.findNavController(HomeFragment.this)
                        .navigate(R.id.action_HomeFragment_to_SettingFragment, args);

            } else if (position == HomeMenuItems.RESTART_DEVICE.ordinal()) {
                AsReaderSDK.getInstance().getDeviceManager().setPower(false);
                try {
                    Thread.sleep(300L);
                } catch (InterruptedException var2) {
                }
                AsReaderSDK.getInstance().getDeviceManager().setPower(true);
//            AsReaderSDK.getDeviceManager().notifyApplicationActive();

            } else if (position == HomeMenuItems.CHANGE_LOG_TYPE.ordinal()) {
                NavHostFragment.findNavController(HomeFragment.this)
                        .navigate(R.id.action_HomeFragment_to_LogTypeFragment, args);

            } else if (position == HomeMenuItems.REMOVE_ALL_LOG_FILES.ordinal()) {
//            LogManager.getInstance().removeAllFiles();
                AsReaderSDK.getInstance().removeSDKLog();
                showToast("ログファイルを削除しました", 1);
            }
        });
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }

    @Override
    public void onClickBackButton() {
    }
}