package jp.co.asterisk.asreader.a60d.demoapp.fragments.menu.setdata;

import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.navigation.fragment.NavHostFragment;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Toast;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import jp.co.asterisk.asreader.a60d.demoapp.R;
import jp.co.asterisk.asreader.a60d.demoapp.adapters.SetColumnDistinctionAdapter;
import jp.co.asterisk.asreader.a60d.demoapp.databinding.FragmentSetColumnDistinctionBinding;
import jp.co.asterisk.asreader.a60d.demoapp.fragments.base.BaseFragment;
import jp.co.asterisk.asreader.a60d.demoapp.util.AppSharedData;
import jp.co.asterisk.asreader.a60d.sdk.type.jvma.JVMADataId;

public class SetColumnDistinction extends BaseFragment {

    FragmentSetColumnDistinctionBinding binding;
    private SetColumnDistinctionAdapter adpTags;
    @Override
    public View onCreateView(
            @NonNull LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState
    ) {
        binding = FragmentSetColumnDistinctionBinding.inflate(inflater, container, false);
        getMainActivity().setToolbarTitle(getString(R.string.toolbar_title_set_column_distinction));
        getMainActivity().setResultTextVisibility(View.VISIBLE);
        getMainActivity().resetResultText();
        return binding.getRoot();
    }

    public void onViewCreated(@NonNull View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        adpTags = new SetColumnDistinctionAdapter(getActivity());
        binding.listview.setAdapter(adpTags);
        adpTags.add("");
        binding.addButton.setOnClickListener(v -> {
            adpTags.add("");
        });
        binding.setButton.setOnClickListener(v -> {
            onClickSetButton(false);
        });
        binding.setButton2.setOnClickListener(v -> {
            onClickSetButton(true);
        });
    }

    private void onClickSetButton(boolean isSetting2){
        getMainActivity().resetResultText();

        JVMADataId dataId = getJVMADataId(binding.columnEditText.getText().toString());
        if (dataId == null){
            showToast(getString(R.string.dialog_message_column_input_error), Toast.LENGTH_SHORT);
            return;
        }

        String offlineSystemPassword = AppSharedData.getInstance().getOfflineSystemPassword();
        String terminalPassword = AppSharedData.getInstance().getTerminalPassword();
        boolean isInputTimeRecord = AppSharedData.getInstance().getIsInputTimeRecord();

        if (!checkPasswords(offlineSystemPassword, terminalPassword)) {
            return;
        }

        setPasswords(offlineSystemPassword, terminalPassword);

        List<String> itemCodeList = new ArrayList<>();
        for (int i = 0; i < adpTags.getCount(); i++) {
            String string = adpTags.getItem(i);
            if (string.equals("") || string.length() == 0) {
                showToast("値が入力されていません", Toast.LENGTH_SHORT);
                return;
            }
            itemCodeList.add(string);
        }
        if (itemCodeList.size() == 0) {
            showToast("値が入力されていません", Toast.LENGTH_SHORT);
            return;
        }
        Map<JVMADataId, List<String>> settingData = new HashMap<>();
        settingData.put(dataId, itemCodeList);

        getASKManager().setSettingDataList(settingData);

        if (!isSetting2){
            getASKManager().sendSettingData(isInputTimeRecord);
        }else {
            getASKManager().sendSettingData2(isInputTimeRecord);
        }
    }

    public JVMADataId getJVMADataId(String hexStr){
        if (hexStr != null && hexStr.length() >0){
            int code = Integer.parseInt(hexStr, 16);
            for (JVMADataId dataID:JVMADataId.values()){
                if (dataID.getCode() == code) {
                    return dataID;
                }
            }
        }
        return null;
    }

    @Override
    public void onClickBackButton() {
        NavHostFragment.findNavController(SetColumnDistinction.this).popBackStack();
    }
}